# Contributing

Any contribution is welcome and we only ask contributors to:

- Create an issues for any significant contribution that would change a large portion of the code base.
- Provide at least integration tests for any contribution
